@@ -470,7 +470,10 @@ src_speech_send (gchar *spcoutput)
     if (busy)
 	return FALSE;
     busy = TRUE;
-    srs_output (spcoutput, strlen(spcoutput)); 
+    if (g_utf8_validate (spcoutput, -1, NULL))
+	srs_output (spcoutput, strlen(spcoutput)); 
+    else
+	    sru_warning ("speech output: invalid UTF-8 received");
     rv = TRUE;
     
 /*     fprintf (stderr, "\n%s", spcoutput); */
