@@ -203,7 +203,8 @@ typedef GList SRWElements;
 
 #define IS_CLIPPING_CONTAINER(a) ( ( (a) != SPI_ROLE_PAGE_TAB ) && 	\
 				   ( (a) != SPI_ROLE_MENU) 	&&	\
-				   ( (a) != -1) )	
+				   ( (a) != -1) )
+#define MAX_PIXELS_PER_COLUMNS	 10000
 /*______________________________</MACROS>_____________________________________*/
 
 /*______________________________< GLOBALS>____________________________________*/
@@ -212,7 +213,7 @@ static SRWElements	*elements 		= NULL;
 static SRWLines		*lines			= NULL;
 static GArray 		*lines_index 		= NULL;
 static gint		id 			= 0,
-			pixels_per_column 	= G_MAXINT;
+			pixels_per_column 	= MAX_PIXELS_PER_COLUMNS;
 static glong		align_flags		= 0;
 static SRWBoundaryRect 	clipping_rectangle;
 /*______________________________</GLOBALS>____________________________________*/
@@ -841,7 +842,7 @@ srw_text_chunk_from_accessible (Accessible	*accessible,
 		    text_chunk->start_offset = start;
 		    text_chunk->end_offset = end ;
 
-		    if (text_chunk->text_bounds.width > 0 && string && strlen (string) )
+		    if (text_chunk->text_bounds.width > 0 && string && g_utf8_strlen (string, -1) )
 			pixels_per_column = MIN (text_chunk->text_bounds.width / g_utf8_strlen (string, -1),
 						pixels_per_column);
 		}
@@ -885,6 +886,9 @@ srw_text_chunk_from_accessible (Accessible	*accessible,
 			text_chunk->text_bounds = text_chunk->clip_bounds;
 			text_chunk->start_offset = 0;
 			text_chunk->end_offset = strlen (string);
+			if (text_chunk->text_bounds.width > 0 && string && g_utf8_strlen (string,-1) )
+			    pixels_per_column = MIN (text_chunk->text_bounds.width / g_utf8_strlen (string, -1),
+						pixels_per_column);
 #ifdef SRW_TEXT_CHUNK_DEBUG
 		fprintf (stderr, "\n\nsrw_text_chunk_from_accessible: NOT text |%s| %20s",
 				    string, 
@@ -2681,7 +2685,7 @@ screen_review_init (SRRectangle *clip_rectangle,
   /*new && init*/
     clip_bounds	 = srw_boundary_rect_new0 ();
     id = 0;
-    pixels_per_column = G_MAXINT;
+    pixels_per_column = MAX_PIXELS_PER_COLUMNS;
     lines_index = NULL;
     if (scope_flags & SRW_SCOPE_WINDOW)
     {
